summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorTom Rini <[email protected]>2024-01-27 07:53:29 -0500
committerTom Rini <[email protected]>2024-01-27 07:53:29 -0500
commitfb5fe1bf84ff489211b333c0165418f0d119d328 (patch)
treefafce57ec527b2586e599584a8e31028507aa23e /include
parente7f9e5eb584dd0b5d1b1ff82fe607d6da9940cc6 (diff)
parent91cc06bcab76dd4b9d07c221b4962283f0984c8e (diff)
Merge tag 'smbios-2024-04-rc1-2' of https://source.denx.de/u-boot/custodians/u-boot-efi
Pull request smbios-2024-04-rc1-2 * Add missing field to SMBIOS type 2 structure definition * Provide smbios command to display smbios table * Enable the command on sandbox and qemu_arm64_defconfig * Provide a python test for the smbios command * Fix copying SMBIOS 2.1 table from QEMU * Correct EFI TCG measurement to assume SMBIOS 3 table
Diffstat (limited to 'include')
-rw-r--r--include/efi_loader.h1
-rw-r--r--include/smbios.h5
2 files changed, 4 insertions, 2 deletions
diff --git a/include/efi_loader.h b/include/efi_loader.h
index d5fca2fa5ef..5c5af4f7fd1 100644
--- a/include/efi_loader.h
+++ b/include/efi_loader.h
@@ -340,6 +340,7 @@ extern const efi_guid_t efi_guid_firmware_management_protocol;
extern const efi_guid_t efi_esrt_guid;
/* GUID of the SMBIOS table */
extern const efi_guid_t smbios_guid;
+extern const efi_guid_t smbios3_guid;
/*GUID of console */
extern const efi_guid_t efi_guid_text_input_protocol;
extern const efi_guid_t efi_guid_text_output_protocol;
diff --git a/include/smbios.h b/include/smbios.h
index b507b9d9d72..e2b7f695846 100644
--- a/include/smbios.h
+++ b/include/smbios.h
@@ -139,6 +139,7 @@ struct __packed smbios_type2 {
u8 chassis_location;
u16 chassis_handle;
u8 board_type;
+ u8 number_contained_objects;
char eos[SMBIOS_STRUCT_EOS_BYTES];
};
@@ -326,10 +327,10 @@ int smbios_update_version_full(void *smbios_tab, const char *version);
* This function clear the device dependent parameters such as
* serial number for the measurement.
*
* @entry: pointer to a struct smbios_entry
* @header: pointer to a struct smbios_header
*/
-void smbios_prepare_measurement(const struct smbios_entry *entry,
+void smbios_prepare_measurement(const struct smbios3_entry *entry,
struct smbios_header *header);
#endif /* _SMBIOS_H_ */
@@ -326,10 +327,10 @@ int smbios_update_version_full(void *smbios_tab, const char *version);
* serial number for the measurement.
*
- * @entry: pointer to a struct smbios_entry
+ * @entry: pointer to a struct smbios3_entry
* @header: pointer to a struct smbios_header
*/